@@ -1,6 +1,5 @@
 from python_codemagic_api.base_endpoint import BaseEndpoint
 
-
 class ApplicationsUtils:
 
     def __init__(self, applications_endpoint):
@@ -14,19 +13,14 @@ class ApplicationsUtils:
                 found_environment_variable = environment_variable
         
         if found_environment_variable == None:
-            self.applications_endpoint.create_env_var(key, value, group, workflow_id, is_secure)
+            a = self.applications_endpoint.create_env_var(key, value, group, workflow_id, is_secure)
         else:
             environment_variable_id = found_environment_variable['id']
             self.applications_endpoint.update_env_var(environment_variable_id, value, is_secure)
 
-    def delete_all_environment_variables(self):
-        env_vars = self.applications_endpoint.get_all_environment_variables().json()
-        for env_var in env_vars:
-            self.applications_endpoint.delete_env_var(self.applications_endpoint.app_id, env_var['id'])
-
-    def get_environment_variable(self, key, group):
-        env_vars = self.applications_endpoint.get_all_environment_variables().json()
-        for env_var in env_vars:
-            if env_var['id'] == key and env_var['group'] == group:
-                return env_var
-        return None
+    def delete_all_environment_variables_for_app(self, app_id):
+        environment_variables = self.applications_endpoint.get_all_environment_variables().json()
+        
+        for environment_variable in environment_variables:
+            self.applications_endpoint.delete_env_var(app_id, environment_variable["id"])
+            
\ No newline at end of file
